@@ -15,7 +15,6 @@
 import json
 import os
 from datetime import timedelta
-from pathlib import Path
 from time import sleep
 from typing import Any, Dict, Optional
 
@@ -275,7 +274,7 @@ class Interaction(LibraryComponent):
 
         ``button`` Defaults to ``left`` if invalid.
 
-        ``click_count`` Defaults to 1.
+        ``clickCount`` Defaults to 1.
 
         ``delay`` Time to wait between mouse-down and mouse-up.
         Defaults to 0.
@@ -575,24 +574,6 @@ class Interaction(LibraryComponent):
             if log_response:
                 logger.debug(response.log)
 
-    @keyword(tags=("Setter", "PageContent"))
-    def upload_file(self, path: str):
-        """Upload file from ``path`` into next file chooser dialog on page.
-
-        ``path`` Path to file to be uploaded.
-
-        Example use:
-
-        | Upload File    ${CURDIR}/test_upload_file
-        | Click          \\#file_chooser
-
-        """
-        p = Path(path)
-        p.resolve(strict=True)
-        with self.playwright.grpc_channel() as stub:
-            response = stub.UploadFile(Request().FilePath(path=str(p)))
-            logger.debug(response.log)
-
     @keyword(tags=("PageContent",))
     def handle_future_dialogs(self, action: DialogAction, prompt_input: str = ""):
         """Handle next dialog on page with ``action``.
