@@ -16,12 +16,11 @@ import json
 from datetime import timedelta
 from typing import Any, Dict, Optional
 
-from robotlibcore import keyword  # type: ignore
 from typing_extensions import Literal
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import logger
+from ..utils import keyword, logger
 from ..utils.data_types import RequestMethod
 
 
@@ -34,19 +33,30 @@ def _get_headers(body: str, headers: Dict):
 
 
 def _format_response(response: Dict):
-    headers = json.loads(response["headers"])
-    response["headers"] = headers
-    if "content-type" in headers and "application/json" in headers["content-type"]:
-        try:
-            response["body"] = json.loads(response["body"])
-        except json.decoder.JSONDecodeError:
-            pass
+    _jsonize_content(response, "body")
+    if "request" in response:
+        request = response["request"]
+        _jsonize_content(request, "postData")
     logger.info(response)
     return response
 
 
+def _jsonize_content(data, bodykey):
+    headers = json.loads(data["headers"])
+    data["headers"] = headers
+    lower_headers = dict((k.lower(), v) for k, v in headers.items())
+    if (
+        "content-type" in lower_headers
+        and "application/json" in lower_headers["content-type"]
+    ):
+        try:
+            data[bodykey] = json.loads(data[bodykey])
+        except json.decoder.JSONDecodeError:
+            pass
+
+
 class Network(LibraryComponent):
-    @keyword(tags=["HTTP"])
+    @keyword(tags=("HTTP",))
     def http(
         self,
         url: str,
@@ -58,12 +68,12 @@ class Network(LibraryComponent):
         """Performs an HTTP request in the current browser context
 
         Accepts the following arguments:
-          - ``url`` <str> The request url, e.g. ``/api/foo``.
-          - ``method`` < ``GET`` | ``POST`` | ``PUT`` | ``PATCH`` | ``DELETE`` | ``HEAD`` > The HTTP method for the request. Defaults to GET.
-          - ``body`` <str> The request body. GET requests cannot have a body. If the body can be parsed as JSON,
+          - ``url`` The request url, e.g. ``/api/foo``.
+          - ``method`` The HTTP method for the request. Defaults to GET.
+          - ``body`` The request body. GET requests cannot have a body. If the body can be parsed as JSON,
           the ``Content-Type`` header for the request will be automatically set to ``application/json``.
           Defaults to None.
-          - ``headers`` <dict> A dictionary of additional request headers. Defaults to None.
+          - ``headers`` A dictionary of additional request headers. Defaults to None.
 
         The response is a Python dictionary with following attributes:
           - ``status`` <int> The status code of the response.
@@ -98,8 +108,6 @@ class Network(LibraryComponent):
 
     def _wait_for_http(self, method: Literal["Request", "Response"], matcher, timeout):
         with self.playwright.grpc_channel() as stub:
-            if not timeout:
-                timeout = self.library.playwright.timeout
             function = getattr(stub, f"WaitFor{method}")
             response = function(
                 Request().HttpCapture(
@@ -109,39 +117,55 @@ class Network(LibraryComponent):
             )
             logger.debug(response.log)
             # Add format response back here
-            return response.body if method == "Request" else response.json
+            return (
+                response.body
+                if method == "Request"
+                else _format_response(json.loads(response.json))
+            )
 
-    @keyword(tags=["Wait", "HTTP"])
-    def wait_for_request(self, matcher: str = "", timeout: str = "") -> Any:
+    @keyword(tags=("Wait", "HTTP"))
+    def wait_for_request(
+        self, matcher: str = "", timeout: Optional[timedelta] = None
+    ) -> Any:
         """Waits for request matching matcher to be made.
 
-        ``matcher`` <str> Request URL string, JavaScript regex or JavaScript function to match request by.
+        ``matcher`` Request URL string, JavaScript regex or JavaScript function to match request by.
         By default (with empty string) matches first available request.
 
-        ``timeout`` <str> Timeout in milliseconds. Uses default timeout of 10 seconds if not set.
+        ``timeout`` Timeout in seconds. Uses default timeout if not set.
 
         """
         return self._wait_for_http("Request", matcher, timeout)
 
-    @keyword(tags=["Wait", "HTTP"])
-    def wait_for_response(self, matcher: str = "", timeout: str = "") -> Any:
+    @keyword(tags=("Wait", "HTTP"))
+    def wait_for_response(
+        self, matcher: str = "", timeout: Optional[timedelta] = None
+    ) -> Any:
         """Waits for response matching matcher and returns python dict with contents.
 
-        ``matcher`` <str> Request URL string, JavaScript regex or JavaScript function to match request by.
+        ``matcher`` Request URL string, JavaScript regex or JavaScript function to match request by.
         By default (with empty string) matches first available request.
 
-        ``timeout`` <str> Timeout in milliseconds. Uses default timeout of 10 seconds if not set.
+        ``timeout`` Timeout in seconds. Uses default timeout if not set.
 
+        The response is a Python dictionary with following attributes:
+          - ``status`` <int> The status code of the response.
+          - ``statusText`` <str> Status text corresponding to ``status``, e.g OK or INTERNAL SERVER ERROR.
+          - ``body`` <dict | str> The response body. If the body can be parsed as a JSON obejct,
+          it will be returned as Python dictionary, otherwise it is returned as a string.
+          - ``headers`` <dict> A dictionary containing all response headers.
+          - ``ok`` <bool> Whether the request was successfull, i.e. the ``status`` is range 200-299.
+          - ``request`` <dict> containing ``method`` <str>, ``headers`` <dict> and ``postData`` <dict> | <str>
         """
         return self._wait_for_http("Response", matcher, timeout)
 
-    @keyword(tags=["Wait", "HTTP"])
+    @keyword(tags=("Wait", "HTTP"))
     def wait_until_network_is_idle(self, timeout: Optional[timedelta] = None):
         """Waits until there has been at least one instance of 500 ms of no network traffic on the page after loading.
 
         Doesn't wait for network traffic that wasn't initiated within 500ms of page load.
 
-        ``timeout`` <str> Timeout in milliseconds. Uses default timeout of 10 seconds if not set.
+        ``timeout`` Timeout in milliseconds. Uses default timeout of 10 seconds if not set.
 
         """
         with self.playwright.grpc_channel() as stub:
@@ -149,3 +173,17 @@ class Network(LibraryComponent):
                 Request().Timeout(timeout=self.get_timeout(timeout))
             )
             logger.debug(response.log)
+
+    @keyword(tags=("Wait", "HTTP"))
+    def wait_for_navigation(self, url: str, timeout: Optional[timedelta] = None):
+        """Waits until page has navigated to given ``url``.
+
+        ``url``  expected navigation target address.
+
+        ``timeout`` Timeout in milliseconds. Uses default timeout of 10 seconds if not set.
+        """
+        with self.playwright.grpc_channel() as stub:
+            response = stub.WaitForNavigation(
+                Request().Url(defaultTimeout=int(self.get_timeout(timeout)), url=url)
+            )
+            logger.debug(response.log)
