@@ -189,7 +189,10 @@ class PlaywrightState(LibraryComponent):
         ``browser`` < ``CURRENT`` | ``ALL`` | str > Id of the browser that belongs to the page to be closed.
         If ``ALL`` is passed, the requested pages depending of the context of all browsers are closed.
         Defaults to CURRENT.
+
+        Returns a list of dictionaries containing id, errors and console messages from the page.
         """
+        result = []
         with self.playwright.grpc_channel() as stub:
             catalog = self.library.get_browser_catalog()
 
@@ -230,7 +233,16 @@ class PlaywrightState(LibraryComponent):
                         if page != "CURRENT":
                             self.switch_page(p)
                         response = stub.ClosePage(Request().Empty())
-                        logger.info(response.log)
+                        if response.log:
+                            logger.info(response.log)
+                        result.append(
+                            {
+                                "errors": json.loads(response.errors),
+                                "console": json.loads(response.console),
+                                "id": response.pageId,
+                            }
+                        )
+        return result
 
     @keyword(tags=("Setter", "BrowserControl"))
     def connect_to_browser(
@@ -269,6 +281,7 @@ class PlaywrightState(LibraryComponent):
         env: Optional[Dict] = None,
         devtools: bool = False,
         slowMo: timedelta = timedelta(seconds=0),
+        channel: Optional[str] = None,
     ) -> str:
 
         """Create a new playwright Browser with specified options.
@@ -318,6 +331,10 @@ class PlaywrightState(LibraryComponent):
 
         ``slowMo`` Slows down Playwright operations by the specified amount of milliseconds.
         Useful so that you can see what is going on. Defaults to no delay.
+
+        ``channel`` Allows to operate against the stock Google Chrome and Microsoft Edge browsers.
+        For more details see:
+        [https://playwright.dev/docs/browsers/#google-chrome--microsoft-edge|Playwright documentation].
         """
         params = locals_to_params(locals())
         params = convert_typed_dict(self.new_context.__annotations__, params)
@@ -328,7 +345,10 @@ class PlaywrightState(LibraryComponent):
         browser_path = self.library.external_browser_executable.get(browser)
         if browser_path:
             params["executablePath"] = browser_path
-
+        if channel and browser != SupportedBrowsers.chromium:
+            raise ValueError(
+                f"Must use {SupportedBrowsers.chromium.name} browser with channel definition"
+            )
         options = json.dumps(params, default=str)
         logger.info(options)
 
